==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/Glue/StartTrigger.pm <==

package Paws::Glue::StartTrigger;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartTrigger');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::StartTriggerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::StartTrigger - Arguments for method StartTrigger on Paws::Glue

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartTrigger on the 
AWS Glue service. Use the attributes of this class
as arguments to method StartTrigger.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StartTrigger.

As an example:

  $service_obj->StartTrigger(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the trigger to start.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StartTrigger in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/Glue/StartTrigger.pm <==

package Paws::Glue::StartTrigger;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartTrigger');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::StartTriggerResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::StartTrigger - Arguments for method StartTrigger on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartTrigger on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method StartTrigger.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StartTrigger.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $StartTriggerResponse = $glue->StartTrigger(
      Name => 'MyNameString',

    );

    # Results:
    my $Name = $StartTriggerResponse->Name;

    # Returns a L<Paws::Glue::StartTriggerResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/StartTrigger>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the trigger to start.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StartTrigger in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
